package com.goafanti.common.dao;

import java.util.List;
import java.util.Map;

import com.goafanti.common.model.UserRole;

public interface UserRoleMapper {
	int insert(UserRole record);

	int insertSelective(UserRole record);

	List<String> findUserIdByRoleId(String rid);

	List<String> findUserIdByRoleIds(List<String> roleIds);

	void deleteByRoleId(List<String> records);

	int deleteByUserRole(Map<String, Object> params);

	int deleteByUserId(String id);

	int insertBatch(Map<String, Object> params);

	List<String> listAuditor();
}